/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#ifndef GUITARSPEC_H_
#define GUITARSPEC_H_

#include <string>
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

class GuitarSpec
{
public:
    GuitarSpec(Builder builder, string model, Type type,
               int string_count, Wood back_wood, Wood top_wood)
    : model(model), builder(builder), type(type), string_count(string_count),
      back_wood(back_wood), top_wood(top_wood)
    {}

    Builder get_builder() const      { return builder; }
    string  get_model() const        { return model; }
    Type    get_type() const         { return type; }
    int     get_string_count() const { return string_count; }
    Wood    get_back_wood() const    { return back_wood; }
    Wood    get_top_wood() const     { return top_wood; }

    bool matches(GuitarSpec *other_spec);

private:
    string model;
    Builder builder;
    Type type;
    int string_count;
    Wood back_wood, top_wood;

    string to_lower(string str);
};

inline string GuitarSpec::to_lower(string str)
{
    transform(str.begin(), str.end(), str.begin(), ::tolower);
    return str;
}

#endif /* GUITARSPEC_H_ */
