/**
 * Based on examples in
 *     Head First Object-Oriented Analysis and Design
 *     by Brett D. McLaughlin, Gary Pollice, and David West
 *     O'Reilly, 2007
 *     ISBN 978-0-596-00867-3
 *
 * Ported from Java by
 *     Ronald Mak
 *     Department of Computer Engineering
 *     San Jose State University
 *     San Jose, CA  95192
 */
#include <vector>
#include "Inventory.h"
#include "Guitar.h"
#include "GuitarSpec.h"
#include "Builder.h"
#include "Type.h"
#include "Wood.h"

using namespace std;

void Inventory::add_guitar(string serial_number, double price,
                           GuitarSpec *spec)
{
    Guitar *guitar = new Guitar(serial_number, price, spec);
    guitars.push_back(guitar);
}

Guitar *Inventory::get_guitar(string serial_number)
{
    for (Guitar *guitar : guitars)
    {
        if (guitar->get_serial_number() == serial_number) return guitar;
    }

    return nullptr;
}

vector<Guitar *> Inventory::search(GuitarSpec *ideal_spec)
{
    vector<Guitar *> matching_guitars;

    for (Guitar *guitar : guitars)
    {
        GuitarSpec *guitar_spec = guitar->get_spec();

        if (guitar_spec->matches(ideal_spec))
        {
            matching_guitars.push_back(guitar);
        }
    }

    return matching_guitars;
}
